@@ -122,14 +122,14 @@ void KCMultiDialogPrivate::_k_clientChanged()
 
         QPushButton *applyButton = q->buttonBox()->button(QDialogButtonBox::Apply);
         if (applyButton) {
-            q->disconnect(applyButton, SIGNAL(clicked()), q, SLOT(slotApplyClicked()));
+            q->disconnect(applyButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotApplyClicked);
             delete applyButton->findChild<KAuth::ObjectDecorator *>();
             applyButton->setEnabled(change);
         }
 
         QPushButton *okButton = q->buttonBox()->button(QDialogButtonBox::Ok);
         if (okButton) {
-            q->disconnect(okButton, SIGNAL(clicked()), q, SLOT(slotOkClicked()));
+            q->disconnect(okButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotOkClicked);
             delete okButton->findChild<KAuth::ObjectDecorator *>();
         }
 
@@ -138,23 +138,23 @@ void KCMultiDialogPrivate::_k_clientChanged()
                 KAuth::ObjectDecorator *decorator = new KAuth::ObjectDecorator(applyButton);
                 decorator->setAuthAction(activeModule->realModule()->authAction());
                 activeModule->realModule()->authAction().setParentWidget(activeModule->realModule());
-                q->connect(decorator, SIGNAL(authorized(KAuth::Action)), SLOT(slotApplyClicked()));
+                q->connect(decorator, &KAuth::ObjectDecorator::authorized, q, &KCMultiDialog::slotApplyClicked);
             }
 
             if (okButton) {
                 KAuth::ObjectDecorator *decorator = new KAuth::ObjectDecorator(okButton);
                 decorator->setAuthAction(activeModule->realModule()->authAction());
                 activeModule->realModule()->authAction().setParentWidget(activeModule->realModule());
-                q->connect(decorator, SIGNAL(authorized(KAuth::Action)), SLOT(slotOkClicked()));
+                q->connect(decorator, &KAuth::ObjectDecorator::authorized, q, &KCMultiDialog::slotOkClicked);
             }
         } else {
             if (applyButton) {
-                q->connect(applyButton, SIGNAL(clicked()), SLOT(slotApplyClicked()));
+                q->connect(applyButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotApplyClicked);
                 delete applyButton->findChild<KAuth::ObjectDecorator *>();
             }
 
             if (okButton) {
-                q->connect(okButton, SIGNAL(clicked()), SLOT(slotOkClicked()));
+                q->connect(okButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotOkClicked);
                 delete okButton->findChild<KAuth::ObjectDecorator *>();
             }
         }
@@ -199,20 +199,6 @@ void KCMultiDialogPrivate::_k_updateHeader(bool use, const QString &message)
     }
 }
 
-void KCMultiDialogPrivate::_k_dialogClosed()
-{
-    // qDebug() ;
-
-    /**
-     * If we don't delete them, the DBUS registration stays, and trying to load the KCMs
-     * in other situations will lead to "module already loaded in Foo," while to the user
-     * doesn't appear so(the dialog is hidden)
-     */
-    for (int i = 0; i < modules.count(); ++i) {
-        modules[ i ].kcm->deleteClient();
-    }
-}
-
 void KCMultiDialogPrivate::init()
 {
     Q_Q(KCMultiDialog);
@@ -227,23 +213,25 @@ void KCMultiDialogPrivate::init()
                                   | QDialogButtonBox::Apply
                                   | QDialogButtonBox::Ok
                                   | QDialogButtonBox::Reset);
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Ok), KStandardGuiItem::ok());
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::cancel());
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::RestoreDefaults), KStandardGuiItem::defaults());
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Apply), KStandardGuiItem::apply());
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Reset), KStandardGuiItem::reset());
+    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Help), KStandardGuiItem::help());
     buttonBox->button(QDialogButtonBox::Reset)->setEnabled(false);
     buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 
-    q->connect(buttonBox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), SLOT(slotApplyClicked()));
-    q->connect(buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()), SLOT(slotOkClicked()));
-    q->connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), SIGNAL(clicked()), SLOT(slotDefaultClicked()));
-    q->connect(buttonBox->button(QDialogButtonBox::Help), SIGNAL(clicked()), SLOT(slotHelpClicked()));
-    q->connect(buttonBox->button(QDialogButtonBox::Reset), SIGNAL(clicked()), SLOT(slotUser1Clicked()));
+    q->connect(buttonBox->button(QDialogButtonBox::Apply), &QAbstractButton::clicked, q, &KCMultiDialog::slotApplyClicked);
+    q->connect(buttonBox->button(QDialogButtonBox::Ok), &QAbstractButton::clicked, q, &KCMultiDialog::slotOkClicked);
+    q->connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QAbstractButton::clicked, q, &KCMultiDialog::slotDefaultClicked);
+    q->connect(buttonBox->button(QDialogButtonBox::Help), &QAbstractButton::clicked, q, &KCMultiDialog::slotHelpClicked);
+    q->connect(buttonBox->button(QDialogButtonBox::Reset), &QAbstractButton::clicked, q, &KCMultiDialog::slotUser1Clicked);
 
     q->setButtonBox(buttonBox);
 
-    q->connect(q, SIGNAL(finished(int)), SLOT(_k_dialogClosed()));
     q->connect(q, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)),
                SLOT(_k_slotCurrentPageChanged(KPageWidgetItem*,KPageWidgetItem*)));
-
-    q->resize(QSize(800, 550));
-    q->adjustSize();
 }
 
 KCMultiDialog::KCMultiDialog(QWidget *parent)
@@ -272,6 +260,13 @@ KCMultiDialog::~KCMultiDialog()
     delete d_ptr;
 }
 
+void KCMultiDialog::showEvent(QShowEvent *ev)
+{
+    resize(QSize(800, 550));
+    adjustSize();
+    KPageDialog::showEvent(ev);
+}
+
 void KCMultiDialog::slotDefaultClicked()
 {
     Q_D(KCMultiDialog);
@@ -357,7 +352,7 @@ void KCMultiDialog::slotApplyClicked()
 
 void KCMultiDialog::slotOkClicked()
 {
-    QPushButton *okButton = buttonBox()->button(QDialogButtonBox::Apply);
+    QPushButton *okButton = buttonBox()->button(QDialogButtonBox::Ok);
     okButton->setFocus();
 
     d_func()->apply();
@@ -380,7 +375,7 @@ void KCMultiDialog::slotHelpClicked()
         }
     }
 
-    QUrl docUrl = QUrl(QStringLiteral("help:/")).resolved(QUrl::fromUserInput(docPath)); // same code as in KHelpClient::invokeHelp
+    QUrl docUrl = QUrl(QStringLiteral("help:/")).resolved(QUrl(docPath)); // same code as in KHelpClient::invokeHelp
     if (docUrl.scheme() == QLatin1String("help") || docUrl.scheme() == QLatin1String("man") || docUrl.scheme() == QLatin1String("info")) {
         QProcess::startDetached(QStringLiteral("khelpcenter"), QStringList() << docUrl.toString());
     } else {
@@ -388,6 +383,21 @@ void KCMultiDialog::slotHelpClicked()
     }
 }
 
+void KCMultiDialog::closeEvent(QCloseEvent *event)
+{
+    Q_D(KCMultiDialog);
+    KPageDialog::closeEvent(event);
+
+    /**
+     * If we don't delete them, the DBUS registration stays, and trying to load the KCMs
+     * in other situations will lead to "module already loaded in Foo," while to the user
+     * doesn't appear so(the dialog is hidden)
+     */
+    Q_FOREACH(auto &proxy, d->modules) {
+        proxy.kcm->deleteClient();
+    }
+}
+
 KPageWidgetItem *KCMultiDialog::addModule(const QString &path, const QStringList &args)
 {
     QString complete = path;
@@ -419,8 +429,12 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
     // qDebug() << moduleInfo.moduleName();
     KPageWidgetItem *item = new KPageWidgetItem(kcm, moduleInfo.moduleName());
 
-    if (kcm->useRootOnlyMessage()) {
-        item->setHeader(QStringLiteral("<b>") + moduleInfo.comment() + QStringLiteral("</b><br><i>") + kcm->rootOnlyMessage() + QStringLiteral("</i>"));
+    if (kcm->realModule() && kcm->realModule()->useRootOnlyMessage()) {
+        item->setHeader(QStringLiteral("<b>") +
+                moduleInfo.comment() +
+                QStringLiteral("</b><br><i>") +
+                kcm->realModule()->rootOnlyMessage() +
+                QStringLiteral("</i>"));
         item->setIcon(KDE::icon(moduleInfo.icon(), QStringList() << QStringLiteral("dialog-warning")));
     } else {
         item->setHeader(moduleInfo.comment());
